@@ -1,6 +1,6 @@
 class OrchestratorConstants:
     def __init__(self):
-        self.IP = "0.0.0.0"
+        self.CoTIP = "0.0.0.0"
         self.COTPORT = 8087
         self.APIPORTARG = '-APIPort'
         self.COTPORTARG = '-CoTPort'
@@ -8,6 +8,7 @@ class OrchestratorConstants:
         self.APIPORTDESC = 'the port address you would like FreeTAKServer to run receive datapackages on not'
         self.IPDESC = "the IP you would like FreeTAKServer to run receive connections on, must be set for private DataPackages to function"
         self.COTPORTDESC = 'the port you would like FreeTAKServer to run receive connections on'
+        self.COTIPDESC = 'the IP you would like FreeTAKServer to run receive connections on'
         self.FULLDESC = 'FreeTAKServer startup settings'
         self.HEALTHCHECK = 'HealthCheck'
         self.LOCALHOST = '127.0.0.1'
\ No newline at end of file
